@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -176,7 +176,7 @@ class Score:
                             beam = None
                         se.append(StemEngraver(timepos, fontsize, v,
                                   voice.m_coldict[timepos],
-                                  beam != None))
+                                  beam is not None))
                         self.m_stem_list.append(se[-1])
                         if beam:
                             beam.add_stem(se[-1])
@@ -192,7 +192,7 @@ class Score:
                             self.m_spanner_list.append(tuplet)
                             se.append(tuplet)
                     else:
-                        #if tuplet != None: tuplet = None
+                        #if tuplet is not None: tuplet = None
                         tuplet = None
             ###################
             # this loop takes care of stuff that is decided on a per-staff-basis
@@ -543,7 +543,7 @@ class Voice:
         if __debug__:
             if self.m_coldict[timepos].m_music.has_key(key):
                 print "warning, adding the same notehead twice", key
-            if (self.m_coldict[timepos].m_duration != None) \
+            if (self.m_coldict[timepos].m_duration is not None) \
                and (self.m_coldict[timepos].m_duration != music.m_duration):
                  print "::", self.m_coldict[timepos].m_duration, music.m_duration
                  print "mpd: warning: All noteheads on the same stem has to have the same length"
@@ -670,6 +670,7 @@ def parse_to_score_object(music):
         tie_is_in_the_air = 0
         x = len(lexer.m_string)
         times = None
+        cur_staff = None
         while lexer.m_idx < x:
             toc, toc_data = lexer.get()
             if toc == Lexer.STAFF:
@@ -684,6 +685,8 @@ def parse_to_score_object(music):
                 cur_staff.announce_timepos(timepos)
                 cur_staff.add_clef(timepos, "violin")
             elif toc == Lexer.VOICE:
+                if not cur_staff:
+                    raise ParseError("Don't use \\addvoice before \\staff")
                 relative_mode = None
                 timepos = Rat(0)
                 cur_voice = cur_staff.add_voice()
