@@ -18,6 +18,7 @@
 import gtk, gnome
 import gu
 import inputwidgets
+import widgets
 import soundcard, mpd
 import dataparser
 
@@ -29,12 +30,14 @@ import types
 import cfg
 
 class Teacher(cfg.ConfigUtils):
-    def __init__(self, exname, app):
+    def __init__(self, exname, app, config):
         cfg.ConfigUtils.__init__(self, exname)
         self.m_app = app
         self.q_status = const.QSTATUS_NO
         self.m_statistics = None
         self.m_timeout_handle = None
+        for k in config.keys():
+            self.set_string(k, dict[k])
     def get_instrument_config(self, num):
         if self.get_bool('override_default_instrument'):
             instr_low = self.get_int('lowest_instrument')
@@ -55,7 +58,7 @@ class Teacher(cfg.ConfigUtils):
                 instr_middle, instr_middle_vel, instr_high, instr_high_vel
     def maybe_auto_new_question(self):
         if self.get_bool('new_question_automatically'):
-            if self.m_timeout_handle == None:
+            if self.m_timeout_handle is None:
                 def remove_timeout(self=self):
                     self.m_timeout_handle = None
                     self.g_view.new_question()
@@ -80,8 +83,8 @@ class MelodicIntervalTeacher(Teacher):
     OK = 0
     ERR_PICKY = 1
     ERR_CONFIGURE = 2
-    def __init__(self, exname, app):
-        Teacher.__init__(self, exname, app)
+    def __init__(self, exname, app, config):
+        Teacher.__init__(self, exname, app, config)
         self.m_tonika = None
         self.m_question = []
     def new_question(self, L, H):
@@ -158,10 +161,15 @@ class MelodicIntervalTeacher(Teacher):
         soundcard.synth.play_track(m)
 
 class LessonbasedTeacher(Teacher):
-    def __init__(self, exname, app):
-        Teacher.__init__(self, exname, app)
+    def __init__(self, exname, app, lesson_collection, lesson_file, config):
+        Teacher.__init__(self, exname, app, config)
         self.m_P = None
         self.m_question = None
+        if lesson_collection or lesson_file:
+            if lesson_collection:
+                self.set_string('lessoncollection', lesson_collection)
+            if lesson_file:
+                self.set_string('lessonfile', lesson_file)
         self.__make_sure_existing_lessonfile_is_selected()
     def set_lessonfile(self, lessoncollection, lessonfile):
         """
@@ -215,10 +223,14 @@ class LessonbasedTeacher(Teacher):
 
 You really should reastart the program now.""")
         if self.m_P.header.musicformat == "cmdline":
-            run = self.m_app.m_ui.dialog_yesno("The lessonfile contain dangerous code because musicformat=\"cmdline\". Run anyway?")
+            run = self.m_app.m_ui.dialog_yesno(_("The lessonfile contain potentially dangerous code because the lesson file set the variable \"musicformat\" to \"cmdline\". Run anyway?"))
             if not run:
                 self.m_P = None
     def configure_exercise(self, lessoncollection, lessonfile, dict):
+    	"""This function should not be called by the constructors.
+	abstract.Teacher and abstract.LessonbasedTeacher does the same job,
+	but in correct order.
+	"""
         if lessoncollection or lessonfile:
             if lessoncollection:
                 self.set_string('lessoncollection', lessoncollection)
@@ -277,7 +289,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
     def on_end_practise(self):
         print "dummy abstract.Gui.on_end_practise", self.m_exname
     def on_key_press_event(self, widget, event):
-        if (self.g_notebook == None or self.g_notebook.get_current_page() == 0) \
+        if (self.g_notebook is None or self.g_notebook.get_current_page() == 0) \
            and event.type == gtk.gdk.KEY_PRESS:
             for s in self.m_key_bindings.keys():
                 if self.keymatch(event, s):
@@ -301,7 +313,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
             else:
                 self.g_statview.update()
     def get_pretty_name(self):
-        return string.replace(const.exercisedata[self.m_exname][0], '_', '')
+        return self.m_t.exercise_data['exercise_pretty_name']
     def _add_auto_new_question_gui(self, box):
         hbox = gu.bHBox(box, False)
         hbox.set_spacing(gnome.ui.PAD_SMALL)
@@ -393,10 +405,39 @@ class LessonbasedGui(Gui):
     def __init__(self, teacher, window):
         Gui.__init__(self, teacher, window)
     def get_pretty_name(self):
-        s = string.replace(const.exercisedata[self.m_exname][0], '_', '')
+        s = self.m_t.exercise_data['exercise_pretty_name']
         if self.get_string('lessoncollection') == 'solfege':
             return "%s - %s" % (s, self.get_string('lessonfile'))
         else:
             return "%s - %s/%s" % (s,
              self.get_string('lessoncollection'), self.get_string('lessonfile'))
+    def add_random_transpose_gui(self):
+        hbox = gu.bHBox(self.config_box, False, False)
+        label = gtk.Label(_("Random transpose:"))
+        label.show()
+        hbox.pack_start(label, False)
+        hbox.set_spacing(6)
+        self.g_random_transpose = gtk.Entry()
+        self.g_random_transpose.set_editable(False)
+        self.g_random_transpose.show()
+        hbox.pack_start(self.g_random_transpose)
+
+        button = gtk.Button(_("Change ..."))
+        button.show()
+        button.connect('clicked', self.run_random_transpose_dialog)
+        hbox.pack_start(button)
+    def run_random_transpose_dialog(self, widget):
+        dlg = widgets.RandomTransposeDialog(self.m_t.m_P.header.random_transpose, self.g_win)
+        response = dlg.run()
+        if response == gtk.RESPONSE_OK:
+            self.m_t.m_P.header.random_transpose = dlg.get_value()
+            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
+        dlg.destroy()
+    def add_select_lessonfile_gui(self):
+        self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
+            self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
+        self.g_lessonfile_selector.show()
+        self.config_box.pack_start(self.g_lessonfile_selector)
+
+
 
