@@ -256,7 +256,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_toptone_status.set_text('')
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
     def on_type(self, button, event=None):
-        if event == None:
+        if event is None:
             self.on_type_left_clicked(button)
         elif event.button == 3:
             self.on_type_right_clicked(button)
@@ -320,7 +320,7 @@ class Gui(abstract.LessonbasedGui):
                 self.m_t.m_P.play_question(question)
                 return
     def on_inversion(self, button, event=None):
-        if event == None:
+        if event is None:
             self.on_inversion_left_clicked(button)
         elif event.button == 3:
             self.on_inversion_right_clicked(button)
@@ -491,10 +491,9 @@ class Gui(abstract.LessonbasedGui):
                     button.get_children()[0].set_name('')
     def show_answer(self):
         fontsize = self.get_int('config/feta_font_size=20')
-        if self.m_t.m_P.header.musicformat == 'chord':
-            clef = mpd.select_clef(self.m_t.m_P.get_music_as_notename_string())
-            self.g_music_displayer.display(r"\staff{\clef %s <%s>}" % (clef, self.m_t.m_P.get_music_as_notename_string()), fontsize)
+        if self.m_t.m_P.get_question()['music'].m_musictype == 'chord':
+            clef = mpd.select_clef(self.m_t.m_P.get_music_as_notename_string('music'))
+            self.g_music_displayer.display(r"\staff{\clef %s <%s>}" % (clef, self.m_t.m_P.get_music_as_notename_string('music')), fontsize)
         else:
-            assert self.m_t.m_P.header.musicformat == 'satb'
             self.g_music_displayer.display(self.m_t.m_P.get_music(), fontsize)
 
