@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2001, 2002, 2003  Tom Cato Amundsen
+# Copyright (C) 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+# 4.69
 """
 prog             The test done before calling
  +statementlist
@@ -40,21 +41,20 @@ assignmentlist peek: 'NAME' '='
 # P singchord-1 sparer jeg ikke noe p  ha en peek2_type(t1, t2)
 # som tester de to neste token.
 
+import sys
+import i18n
+
 if __name__ == "__main__" or __name__ == "dataparser":
-    import sys
     sys.path.append("src")
-    import i18n
     i18n.setup_srcdir()
 
-import sys
 import os, os.path
-import gettext
-import re, string
-import i18n
+import re
 
 tokens = ('NAME', 'STRING', 'OPERATOR', 'INTEGER', 'CHAR', 'EOF')
 for t in tokens:
     globals()[t] = t
+del t
 
 NEW_re = re.compile("""(?:
                         (\s+)|  #space
@@ -85,26 +85,26 @@ lastindex_to_group = {LI_INTEGER: 3,
                     }
 
 class _TranslatedString:
-    def __init__(self, i18n, cname):
-        self.i18n = i18n
+    def __init__(self, i18name, cname):
+        self.i18name = i18name
         self.cname = cname
 
 def dataparser_i18n_func(s):
     return _TranslatedString(_(s), s)
 
-def get_translated_string(dict, name):
+def get_translated_string(d, name):
     for n in i18n.langs():
-        if dict.has_key("%s[%s]" % (name, n)):
-            return dict["%s[%s]" % (name, n)]
-    return dict[name]
+        if "%s[%s" % (name, n) in d:
+            return d["%s[%s]" % (name, n)]
+    return d[name]
 
 class Question(dict):
     def get_toptone(self):
-        if self.has_key('toptone'):
+        if 'toptone' in self:
             return self['toptone']
         return -1
     def get_inversion(self):
-        if self.has_key('inversion'):
+        if 'inversion' in self:
             return self['inversion']
         return -1
     def get_tempo(self):
@@ -113,7 +113,7 @@ class Question(dict):
         """
         Return the untranslated question name
         """
-        if self.has_key('C-name'):
+        if 'C-name' in self:
             return self['C-name']
         return self['name']
     def get_name(self):
@@ -123,15 +123,15 @@ class Question(dict):
         name=_("blabla") if both are available.
         """
         for n in i18n.langs():
-            if self.has_key("name[%s]" % n):
+            if "name[%s]" % n in self:
                 return self["name[%s]" % n]
-        if self.has_key("name"):
+        if "name" in self:
             return self["name"]
-        if self.has_key("name"):
+        if "C-name" in self:
             return self["C-name"]
         return "[no name]"
     def get_music(self):
-        return self['m_lessonfile'].get_music_of_question(self)
+        return self['m_lessonfile'].prepare_music_from_string(self, 'music')
 
 class DataparserException(Exception):
     def __init__(self, filename, lexer):
@@ -141,7 +141,7 @@ class DataparserException(Exception):
     def get_err_context(self, lineno):
         ret = ""
         if lineno > 0:
-           ret += "\n(line %i): %s" % (lineno-1, self.m_lexer.get_line(lineno-1))
+            ret += "\n(line %i): %s" % (lineno-1, self.m_lexer.get_line(lineno-1))
         ret += "\n(line %i): %s" % (lineno, self.m_lexer.get_line(lineno))
         s = self.m_lexer.get_line(lineno+1)
         if s:
@@ -168,6 +168,8 @@ class SyntaxError(DataparserException):
         self.m_msg = msg
     def __str__(self):
         lt = self.m_lexer.m_tokens[self.m_lexer.pos]
+        if lt == ('EOF', None, None, None):
+            return "Unexpected EOF (end of file)"
         ret = "Syntax error in line %i of file '%s': %s" % (lt[3], self.m_filename, self.m_msg)
         ret += self.get_err_context(lt[3])
         return ret
@@ -175,9 +177,9 @@ class SyntaxError(DataparserException):
 
 class UnableToTokenizeException(DataparserException):
     def __init__(self, lexer, lineno, tok):
-         DataparserException.__init__(self, None, lexer)
-         self.m_lineno = lineno
-         self.m_tok = tok
+        DataparserException.__init__(self, None, lexer)
+        self.m_lineno = lineno
+        self.m_tok = tok
     def __str__(self):
         ret = "In line %i of input: does not recognise this string '%s' as a valid token.'" % (self.m_lineno, self.m_tok)
         if self.m_lexer.m_tokens:
@@ -328,13 +330,13 @@ class Dataparser:
         """NAME "=" faktor ("," faktor)* """
         name = self._lexer.scan_any()#('NAME')
         if name in self.reserved_words:
-           raise SyntaxError(self, "Assignment to reserved word '%s'" % name)
+            raise SyntaxError(self, "Assignment to reserved word '%s'" % name)
         self._lexer.scan_any()#('=')
         faktorlist = self.faktorlist()
         if len(faktorlist) == 1:
             if isinstance(faktorlist[0], _TranslatedString):
-                self.context[name] = faktorlist[0].i18n
-                self.context["C-%s"%name] = faktorlist[0].cname
+                self.context[name] = faktorlist[0].i18name
+                self.context["C-%s" % name] = faktorlist[0].cname
             else:
                 self.context[name] = faktorlist[0]
         else:
@@ -418,9 +420,9 @@ class Dataparser:
         # The question block is a little more code because of the shortcut
         # we allow: question { "music string }
         if name == 'question':
-           self.assignmentlist()
-           if self._lexer.peek_type() != '}':
-               self.context['music'] = self.faktor()
+            self.assignmentlist()
+            if self._lexer.peek_type() != '}':
+                self.context['music'] = self.faktor()
         # The single line two below is the code needed if we dont' have
         # shortcuts. Currently the headerblock goes here.
         else:
@@ -428,13 +430,13 @@ class Dataparser:
         self._lexer.scan("}")
         if name == 'question': #FIXME this is code I want to remove.
             for n in self.gd:
-                if not self.context.has_key(n):
+                if not (n in self.context):
                     self.context[n] = self.globals[n]
         self.context = self.globals
     def lookup_name(self, name):
-        if self.context.has_key(name):
+        if name in self.context:
             return self.context[name]
-        elif self.globals.has_key(name):
+        elif name in self.globals:
             return self.globals[name]
         else:
             raise NameLookupException(name, self)
@@ -447,7 +449,7 @@ def test_tokenizer():
     infile = file(sys.argv[1], 'r')
     lexer = Lexer(infile, None)
     infile.close()
-    i=0
+    i = 0
     for t in lexer.m_tokens:
         print i, t
         i += 1
@@ -472,7 +474,7 @@ def main():
     if do_benchmark and (test_what == 'scanner'):
         import time
         t1 = time.clock()
-        for x in xrange(300):
+        for x in xrange(2000):
             p = Dataparser({'dictation': 'dictation',
           'progression': 'progression',
           'harmony': 'harmony',
@@ -500,18 +502,18 @@ def main():
         t1 = time.clock()
         for x in xrange(300):
             f = file(sys.argv[-1], 'r')
-            L = Lexer(f.read(), None)
+            Lexer(f.read(), None)
             f.close()
         print time.clock()-t1
         #print p.questions
         #print p.header
         #print p.globals
     else:
-        print sys.argv
+        #print sys.argv
         for fn in sys.argv[1:]:
-           if (not os.path.isfile(fn)) or (os.path.basename(fn) == "Makefile"):
-               continue
-           p = Dataparser({'dictation': 'dictation',
+            if (not os.path.isfile(fn)) or (os.path.basename(fn) == "Makefile"):
+                continue
+            p = Dataparser({'dictation': 'dictation',
                   'progression': 'progression',
                   'harmony': 'harmony',
                   'sing-chord': 'sing-chord',
@@ -528,12 +530,12 @@ def main():
                   'key': 'key',
                   'semitones': 'semitones',
                   'tempo': (60, 4)}, {'_': dataparser_i18n_func})
-           print fn
-           p.parse_file(fn)
+            #print fn
+            p.parse_file(fn)
 
-           #print "globals", p.globals
-           print "header", p.header
-           print "questions", p.questions
+            #print "globals", p.globals
+            #print "header", p.header
+            #print "questions", p.questions
 
 if __name__ == '__main__':
     main()
