@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@ class _HtmlWidgetCommon(object):
 
 class Font:
     def __init__(self, *f):
-        if f == None or f[0] == None or f[0][0] == None:
+        if f is None or f[0] is None or f[0][0] is None:
             self.m_size = self.m_italic = self.m_bold = self.m_teletype = None
         else:
             self.m_size, self.m_italic, self.m_bold, self.m_teletype = f[0][0]
