@@ -15,6 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'id-by-name',
+    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Id_entify by name")),
+    'icon': 'graphics/idbyname24.png',
+    'toolbar': 5,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 if __name__ == 'idbyname':
     # pydoc ??
     import sys
@@ -34,11 +43,13 @@ import soundcard
 
 
 class Teacher(abstract.LessonbasedTeacher):
+    exercise_data = __exercise_data__
     OK = 0
     ERR_PICKY = 1
     ERR_NO_QUESTION = 2
-    def __init__(self, exname,  app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+    def __init__(self, exname,  app, lesson_collection, lesson_file, config):
+        abstract.LessonbasedTeacher.__init__(self, exname, app,
+                lesson_collection, lesson_file, config)
         self.lessonfileclass = lessonfile.IdByNameLessonfile
         try: # the lessonfile might contain errors.
             self.parse_lessonfile()
@@ -122,10 +133,8 @@ class Gui(abstract.LessonbasedGui):
         ##############
         self.config_box.set_border_width(12)
         self.config_box.set_spacing(18)
-        self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
-            self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
-        self.g_lessonfile_selector.show()
-        self.config_box.pack_start(self.g_lessonfile_selector, False)
+        self.add_select_lessonfile_gui()
+        self.add_random_transpose_gui()
         # -----------------------------------------
         self.g_select_questions_category_box, category_box= gu.hig_category_vbox(
             _("Select questions to ask"))
@@ -177,6 +186,7 @@ class Gui(abstract.LessonbasedGui):
     def update_gui_after_lessonfile_change(self):
         #FIXME simplify conditionals
         if self.m_t.m_P:
+            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
             if self.m_t.m_P.header.musicformat == 'chord':
                 self.g_repeat_arpeggio.show()
             else:
