@@ -15,6 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'id-tone',
+    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Id_entify tone")),
+    'icon': 'graphics/idtone24.png',
+    'toolbar': 8,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import inputwidgets, abstract, const, random, soundcard, gu, mpd, gnome
 import configureoutput
 import gtk
@@ -22,12 +31,14 @@ import gu
 import statistics, statisticsviewer
 
 class Teacher(abstract.Teacher):
+    exercise_data = __exercise_data__
+    #FIXME the following lines
     OK, ERR_PICKY, ERR_TONES = range(3)
     ERR_PICKY = 1
     ERR_CONFIG = 2
     OCTAVES = [-2, -1, 0, 1, 2, 3]
-    def __init__(self, exname, app):
-        abstract.Teacher.__init__(self, exname, app)
+    def __init__(self, exname, app, config):
+        abstract.Teacher.__init__(self, exname, app, config)
         self.m_statistics = statistics.Statistics(self)
         self.m_ask_tones =   {}
         self.m_question = None
