@@ -341,13 +341,13 @@ class AbstractGuitarWidget(gnome.canvas.Canvas):
     def event_callback(self, group, event):
         xp, yp = self.event2xy(event)
         if event.type == gtk.gdk.MOTION_NOTIFY:
-            if xp != None and yp != None:
+            if xp is not None and yp is not None:
                 self.shadow(xp, yp)
             else:
                 if self.m_shadow:
                     self.m_shadow.destroy()
                     self.m_shadow = None
-        if event.type == gtk.gdk.BUTTON_PRESS and xp != None and yp != None:
+        if event.type == gtk.gdk.BUTTON_PRESS and xp is not None and yp is not None:
             midi_int = self.m_stringtuning[yp] + xp
             if self.m_clicked_tones:
                 interval = midi_int - self.m_clicked_tones[-1]
