@@ -19,6 +19,18 @@
 # after we started to use /dev/music. There is no need to take
 # care of channels.
 
+__exercise_data__ = {
+    'exercise_name': 'intervals',
+    'menu_path': '%s/%s' % (_("_Junk"), _("_Intervals")),
+    #'icon': 'graphics/chord24.png',
+    #'toolbar': 0,
+    #'accel_key': gtk.keysyms.F2,
+    #'accel_mods': 0,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
+
 import gtk, gnome
 import gu, widgets
 import mpd, soundcard
@@ -35,6 +47,7 @@ def calc_cent(pitch, cent):
 class Teacher(abstract.Teacher):
     m_intervals = {}
     m_channels = []
+    exercise_data = __exercise_data__
     def play_fifth(self, type):
         self.play_interval(4, 68, 70, 2, 0) # notelen, patch, interval, centadj
     def play_interval(self, notelen, patch, interval, cent, melodic):
