@@ -29,7 +29,7 @@ class NoQuestionException(Exception):
 class LessonfileException(Exception):
     pass
 
-import re, string, types, os, sys
+import re, types, os, sys
 import const
 import random
 import mpd
@@ -72,9 +72,12 @@ predef = {'dictation': 'dictation',
           'harmony': 'harmonic-progression-dictation',
           'harmonic-progression-dictation': 'harmonic-progression-dictation',
           'sing-chord': 'sing-chord',
+          'singanswer': 'singanswer',
           'chord-voicing': 'chord-voicing',
           'chord': 'chord',
           'id-by-name': 'id-by-name',
+          'normal': 'normal',
+          'voice': 'voice',
           'satb': 'satb',
           'cmdline': 'cmdline',
           'horiz': 'horiz',
@@ -96,6 +99,7 @@ lessonfile_functions = {
         '_': dataparser.dataparser_i18n_func,
         '_i': _i, #FIXME
         'play_wav': lambda f: WavPlayerFunctionClass(f),
+        'music': lambda m, t='normal': Music(m, t),
 }
 
 class _Header:
@@ -113,6 +117,7 @@ class _Header:
                            ('filldir', 'horiz'),
                            ('questions_selectable', False),
                            ('have_repeat_slowly_button', False),
+                           ('have_repeat_arpeggio_button', False),
                            ('have_music_displayer', False),
                            ):
             if not self.m_headerdict.has_key(key):
@@ -122,6 +127,11 @@ class _Header:
             return dataparser.get_translated_string(self.m_headerdict, name)
         raise NameError(name)
 
+class Music:
+    def __init__(self, musicdata, musictype='normal'):
+        self.m_musicdata = musicdata
+        self.m_musictype = musictype
+
 
 class LessonfileCommon(object):
     def __init__(self, teacher):
@@ -142,6 +152,9 @@ class LessonfileCommon(object):
         self.m_questions = parser.questions
         for question in self.m_questions:
             question['active'] = 1
+            # FIXMECOMPAT
+            if isinstance(question['music'], basestring):
+                question['music'] = Music(question['music'], self.header.musicformat)
             question['m_lessonfile'] = self
     def select_random_question(self):
         """
@@ -188,7 +201,7 @@ class LessonfileCommon(object):
         assert self.header.random_transpose[0] == 'semitones'
         if self.header.random_transpose == 1:
             return mpd.MusicalPitch().randomize("g", "fis'")
-        elif type(self.header.random_transpose) == type([]):
+        elif type(self.header.random_transpose) in (type([]), type(())):
             return mpd.MusicalPitch().randomize(
               mpd.transpose_notename("c'", self.header.random_transpose[1]),
               mpd.transpose_notename("c'", self.header.random_transpose[2]))
@@ -199,7 +212,7 @@ class LessonfileCommon(object):
         """
         assert self.header.random_transpose[0] in ('key', 'accidentals')
         low, high = self.header.random_transpose[1:3]
-        tone, minmaj = string.split(key, " ")
+        tone, minmaj = key.split()
         k = mpd.MusicalPitch.new_from_notename(tone).get_octave_notename()
         #FIXME this list say what key signatures are allowed in sing-chord
         # lesson files. Get the correct values and document them.
@@ -267,37 +280,38 @@ class LessonfileCommon(object):
         """
         assert self._idx is not None
         return self.m_questions[self._idx].get_cname()
-    def get_music_of_question(self, question):
-        """
-        Return the music of question 'question'. This is complete
-        music code that can be fed to mpd.play_music(...).
-        """
-        if self.header.musicformat == 'chord':
+    def prepare_music_from_string(self, question, varname):
+        if question[varname].m_musictype == 'chord':
             return r"\staff\transpose %s{< %s > }" \
-              % (self.m_transpose.get_octave_notename(), question['music'])
-        elif self.header.musicformat == 'normal':
-            return self.get_music_normal_format(question)
-        elif self.header.musicformat == 'satb':
-            return self.get_music_satb_format(question)
-        elif self.header.musicformat == 'cmdline':
-            return str(question['music'])
+              % (self.m_transpose.get_octave_notename(), question[varname].m_musicdata)
+        elif question[varname].m_musictype == 'normal':
+            return self.prepare_music_string_normal_format(question, varname)
+        elif question[varname].m_musictype == 'satb':
+            return self.prepare_music_string_satb_format(question, varname)
+        elif question[varname].m_musictype == 'voice':
+            return r"\staff\transpose %s{ %s }" \
+              % (self.m_transpose.get_octave_notename(), question[varname].m_musicdata)
+        elif question[varname].m_musictype == 'cmdline':
+            return str(question[varname])
         else:
-            raise LessonfileException("\nLesson file contain illegal assignment 'musicformat=%s'" % self.header.musicformat)
+            raise LessonfileException("\nUknown music type: '%s'" % question[varname].m_musictype)
     def get_music(self):
         """
         Return the music for the currently selected question. This is complete
         music code that can be fed to mpd.play_music(...).
+        FIXMEFIXME Currently this returns the MUSIC variable.
         """
         assert self._idx is not None
-        return self.get_music_of_question(self.m_questions[self._idx])
-    def get_music_satb_format(self, question):
+        return self.prepare_music_from_string(self.m_questions[self._idx], 'music')
+    def prepare_music_string_satb_format(self, question, varname):
         """
         It should not be necessary to call this method directly. Call
-        .get_music() and let that function decide.
+        .get_music() or .prepare_music_from_string() and let that
+        function decide.
         """
-        assert self.header.musicformat == 'satb'
-        v = string.split(question['music'], '|')
-        if question.has_key('key'):
+        assert question[varname].m_musictype == 'satb'
+        v = question[varname].m_musicdata.split('|')
+        if 'key' in question:
             k = question['key']
         else:
             k = "c \major"
@@ -308,95 +322,95 @@ class LessonfileCommon(object):
                 \addvoice{ \stemDown <%s>}
                 """ % (k, v[0], v[1], k, v[2], v[3])
         if self.header.random_transpose:
-            music = string.replace(music, r"\staff",
+            music = music.replace(r"\staff",
                       r"\staff\transpose %s" % self.m_transpose.get_octave_notename())
-            music = string.replace(music, r"\addvoice",
+            music = music.replace(r"\addvoice",
                       r"\addvoice\transpose %s" % self.m_transpose.get_octave_notename())
         return music
-    def get_music_normal_format(self, question):
+    def prepare_music_string_normal_format(self, question, varname):
         """
         It should not be necessary to call this method directly. Call
-        .get_music() and let that function decide.
+        .get_music() or .prepare_music_from_string() and let that
+        function decide.
         """
-        assert self.header.musicformat == 'normal'
-        s = question['music']
+        assert question[varname].m_musictype == 'normal'
         if self.header.random_transpose:
-            s = string.replace(s, r'\staff',
+            s = question[varname].m_musicdata.replace(r'\staff',
                r'\staff\transpose %s' % self.m_transpose.get_octave_notename())
-            s = string.replace(s, r'\addvoice',
+            s = s.replace(r'\addvoice',
                r'\addvoice\transpose %s' % self.m_transpose.get_octave_notename())
-        return s
-    def get_music_as_notename_list(self):
+            return s
+        return question[varname].m_musicdata
+    def get_music_as_notename_list(self, varname):
         """
-        Return a list of notenames representing the question currently
-        selected question
+        Return a list of notenames from the variabale VARNAME in the
+        currently selected question.
 
-        Assert musicformat in ('chord', 'satb')
+        Assert m_musictype in ('chord', 'satb')
         """
-        assert self.header.musicformat in ('chord', 'satb')
         assert self._idx is not None
-        if self.header.musicformat == 'chord':
+        music = self.get_question()[varname]
+        assert music.m_musictype in ('chord', 'satb')
+        if music.m_musictype == 'chord':
             if not self.header.random_transpose:
-                return string.split(self.m_questions[self._idx]['music'])
+                return music.m_musicdata.split()
             v = []
-            for n in string.split(self.m_questions[self._idx]['music']):
+            for n in music.m_musicdata.split():
                 v.append(mpd.MusicalPitch.new_from_notename(n).transpose_by_musicalpitch(
                      self.m_transpose).get_octave_notename())
             return v
-        elif self.header.musicformat == 'satb':
+        elif music.m_musictype == 'satb':
             v = []
-            for n in re.split("\s|\|", self.m_questions[self._idx]['music']):
+            for n in re.split("\s|\|", music.m_musicdata):
                 v.append(mpd.MusicalPitch.new_from_notename(n).transpose_by_musicalpitch(self.m_transpose).get_octave_notename())
             return v
         else:
-            raise LessonfileException("get_music_as_notename_list cannot handle musicformat=%s" % self.header.musicformat)
-    def get_music_as_notename_string(self):
-        """
+            raise LessonfileException("get_music_as_notename_list cannot handle m_musictype==%s" % music.m_musictype)
+    def get_music_as_notename_string(self, varname):
+        """FIXME update version string. Why the fuck do we need this function??
         Return a string with notenames representing the question currently
         selected question.
 
         Assert musicformat in ('chord', 'satb')
         """
-        return " ".join(self.get_music_as_notename_list())
+        return " ".join(self.get_music_as_notename_list(varname))
     def has_question(self):
         """
         Return True if a question is selected.
         """
-        return self._idx != None
-    def play_question(self, question=None):
+        return self._idx is not None
+    def play_question(self, question=None, varname='music'):
         """Play the question. Play the current question if question is none.
+        varname is the name of the variable that contains the music.
         """
         if not question:
             question = self.get_question()
-        if self.header.musicformat == 'cmdline':
-            app.run_external_program(self.get_music(), cfg.get_string('lessoncollections/%s' % self.m_t.get_string('lessoncollection')), "")
-            return
-        elif self.header.musicformat in ('normal', 'satb'):
+        if question[varname].m_musictype == 'cmdline':
+            app.run_external_program(str(question[varname].m_musicdata), cfg.get_string('lessoncollections/%s' % self.m_t.get_string('lessoncollection')), "")
+        elif question[varname].m_musictype in ('normal', 'satb', 'voice'):
             self.play_question_musicformat_normal_satb(question)
-            return
-        elif self.header.musicformat == 'chord':
+        elif question[varname].m_musictype in 'chord':
             self.play_question_musicformat_chord(question)
-            return
-        raise FIXME
+        else:
+            raise FIXME
     def play_question_musicformat_normal_satb(self, question):
-        assert self.header.musicformat in ('normal', 'satb')
         instrument = self.prepare_instrument_list(question)
         mpd.play_music(question.get_music(), self.get_tempo(),
                        instrument[0], instrument[1])
     def play_question_slowly(self, question=None):
         if not question:
             question = self.get_question()
-        assert self.header.musicformat == 'normal'
+        assert question['music'].m_musictype == 'normal'
         self.play_question_musicformat_normal_slowly(question)
     def play_question_musicformat_normal_slowly(self, question):
-        assert self.header.musicformat == 'normal'
+        assert question['music'].m_musictype == 'normal'
         instrument = self.prepare_instrument_list(question)
         bpm = self.get_tempo()
         bpm = (bpm[0]/2, bpm[1])
         mpd.play_music(question.get_music(), bpm,
                        instrument[0], instrument[1])
     def play_question_musicformat_chord(self, question):
-        assert self.header.musicformat == 'chord'
+        assert question['music'].m_musictype == 'chord'
         instrument = self.prepare_instrument_list(question)
         if len(instrument) == 2:
             mpd.play_music(question.get_music(), self.get_tempo(),
@@ -404,7 +418,7 @@ class LessonfileCommon(object):
         elif len(instrument) == 6:
             track = soundcard.Track()
             track.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
-            nlist = self.get_music_as_notename_list()
+            nlist = self.get_music_as_notename_list(varname)
             # set patches
             track.set_patch(0, instrument[0])
             for x in range(1, len(nlist)-1):
@@ -427,26 +441,27 @@ class LessonfileCommon(object):
             soundcard.synth.play_track(track)
         else:
             raise "FIXME"
-    def play_question_arpeggio(self):
-        if self.header.musicformat == 'chord':
-            self.play_question_musicformat_chord_arpeggio()
-        elif self.header.musicformat == 'satb':
-            self.play_question_musicformat_satb_arpeggio()
+    def play_question_arpeggio(self, varname='music'):
+        musictype = self.get_question()[varname].m_musictype
+        if musictype == 'chord':
+            self.play_question_musicformat_chord_arpeggio(varname)
+        elif musictype == 'satb':
+            self.play_question_musicformat_satb_arpeggio(varname)
         else:
-            raise FIXME
-    def play_question_musicformat_chord_arpeggio(self):
+            raise FIXME#We need proper exception handling here
+    def play_question_musicformat_chord_arpeggio(self, varname):
         """FIXME -- for completeness, should this function should take a question argument?
         """
-        assert self.header.musicformat == 'chord'
+        assert self.get_question()[varname].m_musictype == 'chord'
         instrument = self.prepare_instrument_list(self.get_question())
         if len(instrument) == 2:
-            m = self.get_music_as_notename_string()
+            m = self.get_music_as_notename_string(varname)
             mpd.play_music(r"\staff{%s}" % m, self.get_tempo(),
                        instrument[0], instrument[1])
         elif len(instrument) == 6:
             track = soundcard.Track()
             track.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
-            nlist = self.get_music_as_notename_list()
+            nlist = self.get_music_as_notename_list(varname)
             # set patches
             track.set_patch(0, instrument[0])
             for x in range(1, len(nlist)-1):
@@ -464,21 +479,22 @@ class LessonfileCommon(object):
     def play_question_musicformat_satb_arpeggio(self):
         """FIXME -- for completeness, should this function should take a question argument?
         """
+        varname = 'music'
         instrument = self.prepare_instrument_list(self.get_question())
         track = soundcard.Track()
         track.set_bpm(cfg.get_int('config/default_bpm'))
         track.set_patch(0, instrument[0])
         for x in [0, 1]:
-            v = self.get_music_as_notename_list()[x]
-            s = string.split(string.strip(v), " ")
+            v = self.get_music_as_notename_list(varname)[x]
+            s = v.strip().split(" ")
             for n in s:
                 if cfg.get_string('user/sex') == 'female':
                     track.note(4, 0, mpd.notename_to_int(n), instrument[1])
                 else:
                     track.note(4, 0, mpd.notename_to_int(n)-12, instrument[1])
         for x in [2, 3]:
-            v = self.get_music_as_notename_list()[x]
-            s = string.split(string.strip(v), " ")
+            v = self.get_music_as_notename_list(varname)[x]
+            s = v.strip().split(" ")
             for n in s:
                 if cfg.get_string('user/sex') == 'male':
                     track.note(4, 0, mpd.notename_to_int(n), instrument[1])
@@ -603,6 +619,18 @@ class IdByNameLessonfile(LessonfileCommon):
                 print >> sys.stderr, "IdByNameLessonfile.parse_file: discarding question in the lessonfile '%s'\nbecause of missing 'name' variable" % filename
                 continue
 
+class SingAnswerLessonfile(LessonfileCommon):
+    def __init__(self, filename, teacher):
+        """
+        teacher -- the teacher class contructing this lesson file class
+        """
+        LessonfileCommon.__init__(self, teacher)
+        self.parse_file(filename)
+    def parse_file(self, filename):
+        # FIXME this method is only necessary if we to something in it.
+        super(SingAnswerLessonfile, self).parse_file(filename)
+
+
 class ChordLessonfile(LessonfileCommon):
     def __init__(self, filename, teacher):
         LessonfileCommon.__init__(self, teacher)
@@ -656,7 +684,7 @@ class LessonFileManager:
         self.m_db = {}
         self.m_invalid_files = []
         vim_tmpfile_re = re.compile("\..*\.swp")
-        for collection in string.split(cfg.get_string("config/lessoncollections")):
+        for collection in cfg.get_string("config/lessoncollections").split():
             self.m_db[collection] = {}
             if not os.path.isdir(os.path.expanduser(cfg.get_string("lessoncollections/%s" % collection))):
                 continue
@@ -738,13 +766,19 @@ class LessonFileManager:
 
 if __name__ == '__main__':
     import time
-    cfg.initialise(None, "default.config",
-        "~/.solfegerc1.9")
     t1=time.clock()
-    for n in range(10):
+    cfg.initialise(None, "default.config",
+        "~/.solfegerc")
+    t2 = time.clock()
+    for n in range(1):
         #p = LessonfileCommon()
         #p.parse_file(sys.argv[1])
-        p = LessonFileManager()
-    t2 = time.clock()
-    print t2-t1
-    print _
+        #p = LessonFileManager()
+        p = LessonfileCommon(None)
+        p.parse_file(sys.argv[1])
+        print p.m_globals
+        for q in p.m_questions:
+            print q
+    t3 = time.clock()
+    #print t3-t2
+    #print t2-t1
