@@ -15,9 +15,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import __builtin__
+__builtin__.app_running = True
+__builtin__.__exdata__ = []
+
 import sys, os, time, random
 import types
 
+if sys.version_info < (2, 3):
+    print "********************************************************************"
+    print "Solfege need Python 2.3 or newer. The configure script told you so!"
+    print "********************************************************************"
+    sys.exit(-1)
+
 # i18n should be imported very early in program init because it setup
 # the _ and _i functions for the whole program.
 import i18n
@@ -490,10 +500,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         menu.add(item)
         ##############
         # Preferences
-        menu.add(create_stock_menu_item('gtk-preferences', _("Preferences window"), self.open_preferences_window, ag, gtk.keysyms.F12, gtk.gdk.CONTROL_MASK))
+        menu.add(gu.create_stock_menu_item('gtk-preferences', _("Preferences window"), self.open_preferences_window, ag, gtk.keysyms.F12, gtk.gdk.CONTROL_MASK))
         #######
         # Exit
-        menu.add(create_stock_menu_item('gtk-quit', _("_Exit"), self.quit_program, ag, gtk.keysyms.Q, gtk.gdk.CONTROL_MASK))
+        menu.add(gu.create_stock_menu_item('gtk-quit', _("_Exit"), self.quit_program, ag, gtk.keysyms.Q, gtk.gdk.CONTROL_MASK))
         return menu
     def create_view_menu(self, ag):
         menu = gtk.Menu()
@@ -527,13 +537,13 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
 
         if configureoutput.WITH_GTKHTML:
             menu.add(gtk.SeparatorMenuItem())
-            menu.add(create_stock_menu_item('gtk-zoom-in', _("Help viewer zoom in"),
+            menu.add(gu.create_stock_menu_item('gtk-zoom-in', _("Help viewer zoom in"),
                lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_in(),
                ag, gtk.keysyms.plus, gtk.gdk.CONTROL_MASK))
-            menu.add(create_stock_menu_item('gtk-zoom-out', _("Help viewer zoom out"),
+            menu.add(gu.create_stock_menu_item('gtk-zoom-out', _("Help viewer zoom out"),
                lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_out(),
                ag, gtk.keysyms.minus, gtk.gdk.CONTROL_MASK))
-            menu.add(create_stock_menu_item('gtk-zoom-100', _("Help viewer zoom reset"),
+            menu.add(gu.create_stock_menu_item('gtk-zoom-100', _("Help viewer zoom reset"),
                lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_reset(),
                ag, gtk.keysyms.equal, gtk.gdk.CONTROL_MASK))
         return menu
@@ -567,7 +577,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         if self.get_bool("gui/menus_have_tearoff"):
             item = gtk.TearoffMenuItem()
             menu.add(item)
-        item = create_stock_menu_item('gtk-help', _("_Help on current exercise"),
+        item = gu.create_stock_menu_item('gtk-help', _("_Help on current exercise"),
                             lambda o, self=self: self.m_app.please_help_me(),
                             ag, gtk.keysyms.F1, 0)
         menu.add(item)
@@ -633,7 +643,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             if not ex.has_key('toolbar'):
                 continue
             im.set_from_file(ex['icon'])
-            button = self.g_toolbar.append_item(ex['exercise_pretty_name'], None, None, im, None, None)
+            button = self.g_toolbar.append_item(ex['exercise_pretty_name'], ex['exercise_pretty_name'], None, im, None, None)
             button.connect('clicked', lambda button, ex=ex: self.m_app.handle_href("solfege:practice/"+ex['exercise_name']+'/'+ex['exercise_config']))
         self.add_toolbar(self.g_toolbar, "toolbar", "normal", "top", 1, 0, 1)
         s = self.get_string('gui/toolbar_style')
@@ -660,17 +670,6 @@ def create_menu_item(txt, callback, ag, accel_key, accel_mod):
     item.connect('activate', callback)
     return item
 
-def create_stock_menu_item(stock, txt, callback, ag, accel_key, accel_mod):
-    box = gtk.HBox()
-    box.set_spacing(gnome.ui.PAD_SMALL)
-    im = gtk.Image()
-    im.set_from_stock(stock, gtk.ICON_SIZE_MENU)
-    item = gtk.ImageMenuItem(txt)
-    item.set_image(im)
-    item.add_accelerator('activate', ag, accel_key, accel_mod, gtk.ACCEL_VISIBLE)
-    item.connect('activate', callback)
-    return item
-
 if splash_win:
     splash_win.show_progress("running gnome.program_init")
 
