@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,10 +26,10 @@ class MatrixTable(gtk.VBox):
         label = gtk.Label(heading)
         label.set_name("Heading2")
         label.set_alignment(0.0, 0.0)
-        self.pack_start(label, gtk.FALSE)
-        hbox = gu.bHBox(self, gtk.FALSE)
+        self.pack_start(label, False)
+        hbox = gu.bHBox(self, False)
         frame = gtk.Frame()
-        hbox.pack_start(frame, gtk.FALSE)
+        hbox.pack_start(frame, False)
         t = gtk.Table()
         frame.add(t)
         for x in range(len(keys)):
@@ -93,7 +93,7 @@ class PercentagesTable(gtk.Frame):
                 o.destroy()
         for k in statistics.get_keys():
             # FIXME  Has this bug been fixed? This should NEVER happen.
-            if k == None:
+            if k is None:
                 print "WARNING: statistics: key==None. Please, please report to"
                 print "bug-solfege@gnu.org if you get this message. Preferably,"
                 print "make a copy ~/.solfege and ~/.gnome/solfegeX.Y so I can"
@@ -126,7 +126,7 @@ class NewAbstractStatisticsViewer(gtk.ScrolledWindow):
         label = gtk.Label(heading)
         label.set_alignment(0.0, 0.5)
         label.set_name("Heading1")
-        self.vbox.pack_start(label, gtk.FALSE)
+        self.vbox.pack_start(label, False)
         self.m_statistics = statistics
         self.g_tables = gtk.VBox()
         self.g_tables.show()
@@ -149,7 +149,7 @@ class SingIntervalStatisticsViewer(NewAbstractStatisticsViewer):
         self.clear()
         self.g_p = PercentagesTable(self.m_statistics)
         self.g_p.show_all()
-        self.g_tables.pack_start(self.g_p, gtk.FALSE, gtk.FALSE)
+        self.g_tables.pack_start(self.g_p, False, False)
 
 
 
@@ -169,7 +169,7 @@ class StatisticsViewer(NewAbstractStatisticsViewer):
         self.clear()
         self.g_p = PercentagesTable(self.m_statistics)
         self.g_p.show_all()
-        self.g_tables.pack_start(self.g_p, gtk.FALSE)
+        self.g_tables.pack_start(self.g_p, False)
         self.matrix_dict['session'] = MatrixTable(
                                            self.m_statistics.get_label_style(), 
                                            _("Session"),
@@ -196,8 +196,5 @@ class StatisticsViewer(NewAbstractStatisticsViewer):
                                            self.m_statistics.m_total_stat)
 
         for k in ('session', 'today', 'last7', 'total'):
-            self.g_tables.pack_start(self.matrix_dict[k], gtk.FALSE)
-    #def transform_key(self, k):
-    #    return utils.int_to_intervalname(k, 0, 0)
+            self.g_tables.pack_start(self.matrix_dict[k], False)
 
-StatisticsViewer = StatisticsViewer
