@@ -15,6 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'twelve-tone',
+    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Sing _twelvetone")),
+    'icon': 'graphics/twelvetone24.png',
+    'toolbar': 7,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import random
 import gtk
 
@@ -22,8 +31,9 @@ import gu, const, soundcard, mpd, mpd.musicdisplayer
 import abstract, utils
 
 class Teacher(abstract.Teacher):
-    def __init__(self, exname, app):
-        abstract.Teacher.__init__(self, exname, app)
+    exercise_data = __exercise_data__
+    def __init__(self, exname, app, config):
+        abstract.Teacher.__init__(self, exname, app, config)
         self.m_question = None
     def new_question(self):
         self.q_status = const.QSTATUS_NEW
