@@ -140,6 +140,13 @@ def adjust_low_high_to_irange(lowest, highest, irange):
         L = L - (r - (H - L))
     return L, H
 
+def un_escape_url_string(s):
+    r = re.compile("(%([0-9A-F][0-9A-F]))")
+    m = r.search(s)
+    def f(m):
+        return chr(eval("0x%s" % m.groups()[1]))
+    return r.sub(f, s)
+
 
 def parse_url(s):
     # protocol, action, fn, collection, lessonfile, config
@@ -166,6 +173,8 @@ def parse_url(s):
             D[string.strip(n)] = v#eval("\""+v+"\"")
             #else:
             #    D[string.strip(n)] = eval(v)
+    for k in D.keys():
+        D[k] = un_escape_url_string(D[k])
     return m.group('protocol'), m.group('action'), m.group('fn'), \
            m.group('anchor'), m.group('collection'), m.group('lessonfile'), D
 
